import { DestroyRef, EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { IQueryBuilderPossibleRule, IQueryBuilderQuery, IQueryBuilderValueOptions } from '@talenra/ngx-base/query-builder';
import { AttributeItem } from '../shared/models/attributeItem.model';
import { LockedAttributeModel } from '../shared/models/lockedAttributes.model';
import { InboxState } from '../inbox/state/inbox.state';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { FilterToolbarService } from '../filter-toolbar/filter-toolbar.service';
import { AttributeItemSelector } from '../shared/models/attributeItemSelector.model';
import { DetailViewItemModel } from '../shared/models/detailViewItem.model';
import * as i0 from "@angular/core";
/**
 * Responsible for customizing the layout of the data item settings component.
 *
 * ```html
 * <talenra-attributes-settings-layout
 *   *ngIf="!loading; else skeletonLoading"
 *   [attributesSettingsList]="attributeList"
 *   [maxAttributesShown]="maxAttributesShown"
 *   [selectedMainAttributes]="selectedMainAttributes"
 *   [selectedDetailAttributes]="selectedDetailAttributes"
 *   [(isExpanded)]="keyboardService.attributesSettingsExpanded"
 *   (selectedMainAttributesEmitter)="selectedMainAttributesEmitterHandler($event)"
 *   (selectedDetailAttributesEmitter)="selectedDetailAttributesEmitterHandler($event)"
 *   (selectedAllAttributesEmitter)="selectedAllAttributesEmitterHandler($event)"
 * ></talenra-attributes-settings-layout>
 * ```
 */
export declare class AttributesSettingsLayoutComponent implements OnInit, OnChanges {
    /**
     * The used attributes are listed to display them later in the attributes settings UI.
     */
    attributesSettingsList?: AttributeItem[];
    /**
     * The maximum Attributes which are to be shown in the data-items-list-items.
     * Further they are divided in the ui.
     * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings-service.
     * Default value is 12, like chosen in the requirements.
     */
    maxAttributesShown: number;
    /**
     * The maximum Attributes, which are to be shown in the data-items-list-items mutated by the user.
     */
    numberMainAttributesChosenByUser: number;
    /**
     * The boolean value is used to expand the attributes settings UI.
     */
    isExpanded: boolean;
    /**
     * Sets the selected main attributes.
     */
    selectedMainAttributes: AttributeItem[];
    /**
     * Sets the selected detail attributes.
     */
    selectedDetailAttributes: AttributeItem[];
    /**
     * List of attributes key which are used to lock the attributes in the attribute settings.
     * Gets updated by the used attributes in the filter toolbar.
     */
    lockedAttributes: LockedAttributeModel[];
    /**
     * The selected tab.
     */
    selectedTab: import("@angular/core").ModelSignal<string>;
    /**
     * The query that is currently selected.
     */
    query: import("@angular/core").ModelSignal<IQueryBuilderQuery>;
    /**
     * The possible rules that can be selected.
     */
    possibleRules: import("@angular/core").InputSignal<IQueryBuilderPossibleRule[]>;
    /**
     * The values that can be selected in connection to each rule identifier.
     */
    possibleOptions: import("@angular/core").InputSignal<IQueryBuilderValueOptions[]>;
    /**
     * Emits the main selected attributes.
     */
    selectedMainAttributesEmitter: EventEmitter<AttributeItem[]>;
    /**
     * Emits the detail selected attributes.
     */
    selectedDetailAttributesEmitter: EventEmitter<AttributeItem[]>;
    /**
     * Emits the all selected attributes.
     */
    selectedAllAttributesEmitter: EventEmitter<AttributeItem[]>;
    /**
     * The boolean value is used to expand the attributes settings UI.
     */
    isExpandedChange: EventEmitter<boolean>;
    /**
     * The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserEmitter: EventEmitter<number>;
    /**
     * The tab bar items.
     */
    tabBarItems: DetailViewItemModel[];
    /**
     * List of available attributes for the filter selection.
     */
    allFilterSelectionAttributes: AttributeItemSelector[];
    /**
     * Maximal number of filters that can be selected.
     */
    maxFilterSelected: number;
    /**
     * The used services and references.
     */
    filterToolbarService: FilterToolbarService;
    inboxState: InboxState;
    keyboardService: KeyboardService;
    destroyRef: DestroyRef;
    /**
     * Emits the selected main attributes.
     * @param selectedMainAttributes The selected main attributes.
     */
    selectedMainAttributesEmitterHandler(selectedMainAttributes: AttributeItem[]): void;
    /**
     * Emits the selected detail attributes.
     * @param selectedDetailAttributes The selected detail attributes.
     */
    selectedDetailAttributesEmitterHandler(selectedDetailAttributes: AttributeItem[]): void;
    /**
     * Emits the selected all attributes.
     * @param selectedAllAttributes All selected attributes.
     */
    selectedAllAttributesEmitterHandler(selectedAllAttributes: AttributeItem[]): void;
    /**
     * Emits the expanded change.
     * @param $event The boolean value is used to expand the attributes settings UI.
     */
    expandedChangeHandler($event: boolean): void;
    /**
     * Emits the number main attributes chosen by user change.
     * @param $event The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserHandler($event: number): void;
    /**
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes in the component.
     * @internal
     **/
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Change in the selected filter attributes.
     * @param attributes The selected filter attributes.
     */
    selectedFilterAttributesSelectorChange(attributes: AttributeItemSelector[]): void;
    /**
     * Change the selected tab.
     * @param $event The selected tab.
     */
    selectedTabChange($event: string): void;
    /**
     * Method to emit the close button and close the inbox detail view
     */
    onCloseClick(): void;
    /**
     * Method to reset the advanced filter.
     * @protected
     */
    protected resetAdvancedFilter(): void;
    protected onClickOutside(event: MouseEvent): void;
    /**
     * Changes the tab.
     * @param tab The tab.
     * @protected
     */
    protected changeTab(tab: string): void;
    /**
     * Initializes the component.
     * @protected
     */
    protected initializeComponent(): void;
    /**
     * Confirms the advanced filter.
     * @protected
     */
    protected confirmAdvancedFilter(): void;
    /**
     * Sets the all available attributes for the filter selection.
     * @param selectedAllAttributes The selected all attributes.
     * @private
     */
    private setAllFilterSelectionAttributes;
    static ɵfac: i0.ɵɵFactoryDeclaration<AttributesSettingsLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AttributesSettingsLayoutComponent, "talenra-attributes-settings-layout", never, { "attributesSettingsList": { "alias": "attributesSettingsList"; "required": false; }; "maxAttributesShown": { "alias": "maxAttributesShown"; "required": false; }; "numberMainAttributesChosenByUser": { "alias": "numberMainAttributesChosenByUser"; "required": false; }; "isExpanded": { "alias": "isExpanded"; "required": false; }; "selectedMainAttributes": { "alias": "selectedMainAttributes"; "required": false; }; "selectedDetailAttributes": { "alias": "selectedDetailAttributes"; "required": false; }; "lockedAttributes": { "alias": "lockedAttributes"; "required": false; }; "selectedTab": { "alias": "selectedTab"; "required": false; "isSignal": true; }; "query": { "alias": "query"; "required": false; "isSignal": true; }; "possibleRules": { "alias": "possibleRules"; "required": false; "isSignal": true; }; "possibleOptions": { "alias": "possibleOptions"; "required": false; "isSignal": true; }; }, { "selectedTab": "selectedTabChange"; "query": "queryChange"; "selectedMainAttributesEmitter": "selectedMainAttributesEmitter"; "selectedDetailAttributesEmitter": "selectedDetailAttributesEmitter"; "selectedAllAttributesEmitter": "selectedAllAttributesEmitter"; "isExpandedChange": "isExpandedChange"; "numberMainAttributesChosenByUserEmitter": "numberMainAttributesChosenByUserEmitter"; }, never, ["*"], false, never>;
}
