import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FilterToolbarService } from './filter-toolbar.service';
import { FilterStateService } from './state/filter.state';
import { AttributeItem } from '../shared/models/attributeItem.model';
import { FilterAttributesInput } from '../shared/models/filterAttributesInput.model';
import { IconFiltersInput } from '../shared/models/iconFiltersInput.model';
import { IconInput } from '../shared/models/iconInput.model';
import { InboxState } from '../inbox/state/inbox.state';
import { MainFacadeSetterService } from '../inbox/services/main-facade-setter.service';
import { PresetGroup } from '../shared/models/presetGroup.model';
import { UpdatePresetsService } from '../inbox/services/update-presets.service';
import { ChangedPresetValuesService } from '../inbox/services/changed-preset-values.service';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { InboxToolbarService } from '../inbox-toolbar/inbox-toolbar.service';
import * as i0 from "@angular/core";
/**
 * FilterToolbar is used to display the filter toolbar in the inbox toolbar.
 *
 * ```html
 * <talenra-filter-toolbar
 *   [scrollBarShadow]="headerHidden()"
 *   [searchedAndFilteredDataItems]="filteredDataItems"
 * ></talenra-filter-toolbar>
 * ```
 */
export declare class FilterToolbarComponent implements OnInit, OnDestroy, OnChanges {
    /**
     * The presetGroup for the filter toolbar.
     * Used to get the active preset and the filter/sort values.
     */
    presetGroups: PresetGroup[];
    /**
     * The data items inputted by the consuming application.
     * Used to check the amount of results. Compared with the amount of searched and filtered data items.
     */
    dataItemsLength: number | undefined;
    /**
     * Length of list of all data items that are displayed in the inbox after the search and filter process.
     * Used to check the amount of results. Set to this value if not in sync with data items lenght.
     */
    searchedAndFilteredDataItemsLength: number;
    /**
     * List of given IconFilters.
     */
    iconFilters: IconInput[];
    /**
     * Emitter to reset the preset to the default preset.
     */
    resetPresetEmitter: EventEmitter<boolean>;
    /**
     * The active preset name.
     * Used to check if the current preset is the same as the new preset.
     * If not, the filters and buffer are reset.
     */
    currentPresetName?: [string, string];
    /**
     * The number of results that are displayed in the inbox.
     * Is given by the actual filtering or via the inbox configuration.
     */
    hitsNumber: number;
    /**
     * The used service.
     */
    filterToolbarService: FilterToolbarService;
    inboxToolbarService: InboxToolbarService;
    inboxState: InboxState;
    setInboxConfigurationService: MainFacadeSetterService;
    filterState: FilterStateService;
    updatePresetsService: UpdatePresetsService;
    changedValuesService: ChangedPresetValuesService;
    keyboardService: KeyboardService;
    /**
     * Subscriptions for the filter toolbar component.
     * @internal
     */
    private initialSubscriptions;
    /**
     * Subscriptions for the filter toolbar component.
     * @internal
     */
    private subscriptions;
    /**
     * Initializes the filter toolbar component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Function to handle the changes in the filter toolbar component.
     * @param changes The changes.
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Function to reset the preset to the default preset.
     */
    resetPresetToDefault(): void;
    /**
     * Function to delete all filters from the filter selection and toolbar.
     */
    deleteFilters(): void;
    /**
     * Function to handle the preset groups for the filter toolbar.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     */
    handlePresetGroupsForFilterToolbar(groupName: string, presetName: string): void;
    /**
     * Function to calculate the filter results.
     * @param filterType The filter type.
     * @param activePresetName The active preset.
     * @param allSelectedAttribute The all selected attribute.
     * @param filterAttribute The filter attribute.
     */
    setFilterValues(filterType: string, activePresetName: [string, string], allSelectedAttribute: AttributeItem | 'icon', filterAttribute: FilterAttributesInput | IconFiltersInput): void;
    /**
     * Function to get the amount of results.
     */
    amountOfResults(): void;
    /**
     * Function to open the sort menu.
     * @param menu The menu.
     * @param mouseEvent The mouse event.
     */
    openSidePanelMenu(menu: string, mouseEvent: MouseEvent): void;
    /**
     * Set the selected attribute in the filter selection side panel.
     */
    setSelectedAttributeInFilterSelectionSidePanel(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterToolbarComponent, "talenra-filter-toolbar", never, { "presetGroups": { "alias": "presetGroups"; "required": false; }; "dataItemsLength": { "alias": "dataItemsLength"; "required": false; }; "searchedAndFilteredDataItemsLength": { "alias": "searchedAndFilteredDataItemsLength"; "required": false; }; "iconFilters": { "alias": "iconFilters"; "required": false; }; }, { "resetPresetEmitter": "resetPresetEmitter"; }, never, never, false, never>;
}
