import { BehaviorSubject } from 'rxjs';
import { SortAttributesInput } from '../shared/models/sortAttributesInput.model';
import { AttributeItemSelector } from '../shared/models/attributeItemSelector.model';
import { FilterAttributesInput } from '../shared/models/filterAttributesInput.model';
import { PresetGroup } from '../shared/models/presetGroup.model';
import { FilterAttribute } from '../shared/interfaces/filterAttribute.interface';
import { SelectionModel } from '../shared/models/selection.model';
import * as i0 from "@angular/core";
/**
 * FilterToolbarService is used to share data between the filter toolbar and other components in the library.
 * The calculation of each filter is also done here.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { FilterToolbarService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class FilterToolbarService {
    /**
     * The charRangeAlphabet is the alphabet that is used for the char range filter.
     * @internal
     */
    readonly charRangeAlphabet = "A\u00C0\u00C1\u00C2\u00C3\u00C4\u00C5\u00C6BC\u00C7D\u00D0E\u00C8\u00C9\u00CA\u00CBFGHI\u00CC\u00CD\u00CE\u00CFJKLMN\u00D1O\u00D2\u00D3\u00D4\u00D5\u00D6PQRSTU\u00D9\u00DA\u00DB\u00DCVWXY\u00DD\u00FFZ0123456789!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~\u20AC\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\u017D\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\u017E\u0178\u00A1\u00A2\u00A3\u00A4\u00A5\u00A6\u00A7\u00A8\u00A9\u00AA\u00AB\u00AC\u00AE\u00AF\u00B0\u00B1\u00B2\u00B3\u00B4\u00B5\u00B6\u00B7\u00B8\u00B9\u00BA\u00BB\u00BC\u00BD\u00BE\u00BF\u00D7\u00D8\u00DE\u00DF\u00F0\u00F7\u00FE";
    /**
     * Is set if the inbox is initialized.
     * @internal
     */
    readonly inboxInitialized$: BehaviorSubject<boolean>;
    /**
     * Sets the value that the sorting should start after filtering.
     * @internal
     */
    readonly startSorting$: BehaviorSubject<boolean>;
    /**
     * The filtered and sorted data items.
     * @internal
     */
    readonly filteredSortedDataItems$: BehaviorSubject<any[]>;
    /**
     * The original list of data items inputted by the consuming application.
     * @internal
     */
    readonly originalDataItems$: BehaviorSubject<any[]>;
    /**
     * All information about the used filters are inside this subject.
     * @internal
     */
    readonly filterSelections$: BehaviorSubject<Map<string, [string, string | boolean | string[] | number[] | Date[]]>>;
    /**
     * The selected sort attributes.
     * @internal
     */
    readonly sortSelection$: BehaviorSubject<SortAttributesInput[]>;
    /**
     * List of selected attributes for the filter selection.
     */
    readonly selectedFilterSelectionAttributes$: BehaviorSubject<AttributeItemSelector[]>;
    /**
     * The selected sort attributes amount.
     * @internal
     */
    selectedSortSelectionAttributesAmount$: import("@angular/core").WritableSignal<number>;
    /**
     * The selected and active filter attributes amount.
     * @internal
     */
    activeAdvancedFiltersAmount$: import("@angular/core").WritableSignal<number>;
    /**
     * Reset the filter selections in the filter selection side panel.
     */
    resetFilterSelectionAttribute$: import("@angular/core").WritableSignal<boolean>;
    /**
     * Map with all identifiers and the possible selections for the filter.
     */
    identifierWithPossibleSelection?: Map<string, SelectionModel[]>;
    /**
     * This function is to check if a string value is contained in all the string attributes of a data item.
     * @internal
     */
    private dataItemsClass;
    /**
     * The inbox service.
     * @internal
     */
    private inboxState;
    /**
     * The filter state service.
     */
    private filterState;
    /**
     * The changed values service.
     */
    private changedValuesService;
    /**
     * Sets the inboxInitialized subject.
     * @param key The value if the inbox is initialized.
     * @internal
     */
    setInboxInitialized(key: boolean): void;
    /**
     * Sets the start sorting subject. If set to true, the sorting will start.
     * @param key The value if the inbox is initialized.
     * @internal
     */
    setStartSorting(key: boolean): void;
    /**
     * Sets the selectedDataItems subject.
     * @param key The value of the selected data items.
     * @internal
     */
    setFilteredSortedDataItems(key: any[]): void;
    /**
     * Sets the dataItemsSubject subject.
     * @param key The value of the unchanged list of data items.
     * @internal
     */
    setOriginalDataItems(key: any[]): void;
    /**
     * Set the sort subject.
     * @param key The sort subject.
     * @internal
     */
    setSortSelection(key: SortAttributesInput[]): void;
    /**
     * Set the filter selections.
     * @param key The filter selections.
     */
    setSelectedFilterSelectionAttributes(key: AttributeItemSelector[]): void;
    /**
     * Set the sort subject.
     * @param key The sort subject.
     * @internal
     */
    setSelectedSortSelectionAttributesAmount(key: number): void;
    /**
     * Set the reset filter selection attribute flag.
     * @param key The flag to reset the filter selection attribute.
     */
    setResetFilterSelectionAttribute(key: boolean): void;
    /**
     * Set the amount of active advanced filters.
     * @internal
     */
    setActiveAdvancedFiltersAmount(): void;
    /**
     * The main filter function which is called when a filter is used. It filters the data items based on the filter type.
     * @internal
     */
    mainFilterFunction(): void;
    /**
     * Function to filter the data items based on the icon filter.
     * @param label The label of the icon filter.
     * @param value The value of the icon filter.
     * @param filteredDataItems The data items that are already filtered.
     * @returns
     * @internal
     */
    iconFunction(label: string, value: string | boolean | number[] | string[] | undefined, filteredDataItems: any[]): any[];
    /**
     * Function to filter the data items based on the selection filter.
     * @param label The label of the selection filter.
     * @param values The values of the selection filter.
     * @param filteredDataItems The data items that are already filtered.
     * @returns
     * @internal
     */
    selectionFunction(label: string, values: string | boolean | number[] | string[] | Date[] | undefined, filteredDataItems: any[]): any[];
    /**
     * Function to filter the data items based on the date range filter.
     * @param label The label of the date range filter.
     * @param values The values of the date range filter.
     * @param filteredDataItems The data items that are already filtered.
     * @returns
     * @internal
     */
    dateRangeFunction(label: string, values: any, filteredDataItems: any[]): any[];
    /**
     * Function to check if values are in chosen range.
     * @param label The label of the char range filter.
     * @param values The values of the char range filter.
     * @param filteredDataItems The data items that are already filtered.
     * @internal
     */
    numberRangeFunction(label: string, values: any, filteredDataItems: any[]): any[];
    /**
     * Function to check if values are in chosen range.
     * @param label The label of the char range filter.
     * @param values The values of the char range filter.
     * @param filteredDataItems The data items that are already filtered.
     * @internal
     */
    charRangeFunction(label: string, values: any, filteredDataItems: any[]): any[];
    /**
     * Sorts the string values.
     * Returns -1 if a is smaller than b.
     * @param a String to compare.
     * @param b String to compare.
     * @internal
     */
    sortString(a: string, b: string): 1 | -1;
    /**
     * Important function to save the selected values of the filters to the activeFilters array.
     * The changes trigger the filter functions in the filter toolbar service.
     * @param filterType The type of the filter.
     * @param filterIdentifier The identifier of the filter.
     * @param value The value of the filter.
     */
    valuesSelected(filterType: string, filterIdentifier: string, value: string | boolean | string[] | number[]): void;
    /**
     * Function to delete or clean the filter from the filter toolbar.
     * If deleteOrClean = true, the filter will be deleted.
     * If deleteOrClean = false, the filter will be cleaned.
     * @param identifier The identifier of the filter.
     * @param deleteOrClean If deleteOrClean = true, the filter will be deleted.
     */
    deleteOrCleanFilterFromToolbar(identifier: string, deleteOrClean: boolean): void;
    /**
     * Set the active filter and icon filter state of the inbox.
     */
    setActiveFilterAndIconFilterState(): void;
    /**
     * Function to check if the filter values have changed compared to the values in the preset.
     * If the values have changed, the attributeSortOrFilterUsedSubject$ is set to true.
     */
    checkFilterValuesChangedComparedToValuesInPreset(presetGroups: PresetGroup[]): void;
    /**
     * Transforms the active filter to the filter attribute interface.
     * @param activeFilter The active filter.
     */
    transformActiveFilter(activeFilter: FilterAttributesInput[]): FilterAttribute[];
    /**
     * Get the filter value key from the possible options.
     * @param filterIdentifier
     * @param filterValue
     */
    getFilterValueKeyFromPossibleOptions(filterIdentifier: string, filterValue: string): string;
    /**
     * Replaces specific char in a string at a specific index.
     * @param str String to replace char in.
     * @param index Index where to replace in str.
     * @param replacement Replacement char.
     * @internal
     */
    private replaceCharAt;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterToolbarService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilterToolbarService>;
}
