import { EventEmitter, OnInit } from '@angular/core';
import { FormGroup, UntypedFormGroup } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Range filter component, which enables three possible filter types:
 * 1. date-range
 * 2. char-range
 * 3. number-range
 * All three filter types are used to filter the data items by a range of values.
 * The filter displays two input fields, one for the start value and one for the end value.
 * An error message for the start and end input field is displayed if the input is syntactically false.
 *
 * ```html
 * <talenra-range-filter
 *   [filterLabel]="filterLabel"
 *   [filterIdentifier]="filterIdentifier"
 *   [filterType]="filterType"
 *   (deleteOrCleanFilterFromToolbar)="deleteOrCleanFilterFromToolbar($event.filterIdentifier, $event.deleteOrClean)"
 *   (valuesSelected)="valuesSelected(filterType, $event.filterIdentifier, $event.value)"
 * ></talenra-range-filter>
 * ```
 */
export declare class RangeFilterComponent implements OnInit {
    /**
     * The filterDisplayedName is the name that is displayed in the filter toolbar.
     */
    filterLabel: string;
    /**
     * The filterIdentifier is the name that is used to identify the filter.
     */
    filterIdentifier: string;
    /**
     * The filterType is the type of the filter.
     */
    filterType: string;
    /**
     * The valuesSelected event is emitted when the user selects a value in the filter.
     */
    valuesSelected: EventEmitter<{
        filterIdentifier: string;
        value: string[] | number[];
    }>;
    /**
     * The deleteOrCleanFilterFromToolbar event is emitted when the user deletes or cleans the filter from the filter toolbar.
     */
    deleteOrCleanFilterFromToolbar: EventEmitter<{
        filterLabel: string;
        filterIdentifier: string;
        deleteOrClean: boolean;
    }>;
    /**
     * The filterValues are the values that are used to filter the data items.
     */
    reactiveForm: UntypedFormGroup;
    /**
     *  The date range values.
     */
    dateRange: FormGroup;
    /**
     * The falseEndInput is used to check if the end input is syntactically false.
     */
    falseEndInput: boolean;
    /**
     * The inboxState is used to get the active view name.
     * @private
     */
    private inboxState;
    /**
     * The filterState is used to get the filter values from the filter toolbar.
     * @private
     */
    private filterState;
    /**
     * The filterToolbarService is used to sort the values to check if the end input is syntactically false.
     * @private
     */
    private filterToolbarService;
    /**
     * This method is called when the component is initialized.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Function is necessary to delete the filter from the filter toolbar.
     * Furthermore, the previous filterings with the deleted filter will be ignored.
     * @param deleteOrClean The boolean value if the filter is to be removed or reset.
     * @param mouseEvent The mouse event.
     */
    onDeleteOrCleanFilterFromToolbar(deleteOrClean: boolean, mouseEvent: MouseEvent): void;
    /**
     * Auxiliary method to check if start string is before the end string of the given alphabet.
     * @param start The start string.
     * @param end The end string.
     */
    checkEndInputFalse(start: string, end: string): void;
    /**
     * Function is necessary to prevent the enter key from being pressed.
     * @param event The event if the enter key is pressed.
     */
    onEnterKey(event: Event): void;
    /**
     * All selected filters will be saved in the map with there defintion and values
     * @param filterIdentifier The filterIdentifier is the name that is used to identify the filter.
     * @param event The event is the selected value of the filter.
     * @private
     */
    private onValuesSelected;
    /**
     * Function is necessary to reset the values of the filter.
     * @private
     */
    private resetValues;
    static ɵfac: i0.ɵɵFactoryDeclaration<RangeFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RangeFilterComponent, "talenra-range-filter", never, { "filterLabel": { "alias": "filterLabel"; "required": false; }; "filterIdentifier": { "alias": "filterIdentifier"; "required": false; }; "filterType": { "alias": "filterType"; "required": false; }; }, { "valuesSelected": "valuesSelected"; "deleteOrCleanFilterFromToolbar": "deleteOrCleanFilterFromToolbar"; }, never, never, false, never>;
}
