import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { SelectComponent } from '@talenra/ngx-base/select';
import { SelectionModel } from '../../shared/models/selection.model';
import { SelectedFilterValueModel } from '../../shared/models/selectedFilterValue.model';
import * as i0 from "@angular/core";
/**
 * The selection filter component is a component to show a selected item from a pool of items.
 * There is a multiple selection possible.
 *
 * @example single selection
 *   <talenra-selection-filter
 *     [filterIdentifier]="filterIdentifier"
 *     [filterLabel]="label"
 *     [multiple]="false"
 *     [filterType]="filterType"
 *     [valuesOfCategory]="possibleSelection"
 *     (deleteOrCleanFilterFromToolbar)="deleteOrCleanFilterFromToolbar($event.filterIdentifier, $event.deleteOrClean)"
 *     (valuesSelected)="valuesSelected(filterType, $event.filterIdentifier, $event.value)">
 *   </talenra-selection-filter>
 *
 * @example multiple selection
 *   <talenra-selection-filter
 *     [filterIdentifier]="filterIdentifier"
 *     [filterLabel]="label"
 *     [multiple]="true"
 *     [filterType]="filterType"
 *     [valuesOfCategory]="possibleSelection"
 *     (deleteOrCleanFilterFromToolbar)="deleteOrCleanFilterFromToolbar($event.filterIdentifier, $event.deleteOrClean)"
 *     (valuesSelected)="valuesSelected(filterType, $event.filterIdentifier, $event.value)">
 *   </talenra-selection-filter>
 */
export declare class SelectionFilterComponent implements OnInit, OnChanges {
    /**
     * The displayed name of the filter in the filter toolbar.
     */
    filterLabel: string;
    /**
     * The identifier of the filter.
     */
    filterIdentifier: string;
    /**
     * The possible values of the filter.
     */
    possibleValues?: SelectionModel[];
    /**
     * Boolean if the filter is a single or multi select.
     */
    multiple?: boolean;
    /**
     * The type of the filter.
     */
    filterType: string;
    /**
     * Event emitter to send the selected values to the parent component.
     */
    valuesSelected: EventEmitter<SelectedFilterValueModel>;
    /**
     * Event emitter to send the filter to the parent component to delete it from the filter toolbar.
     */
    deleteOrCleanFilterFromToolbar: EventEmitter<{
        filterLabel: string;
        filterIdentifier: string;
        deleteOrClean: boolean;
    }>;
    /**
     * The select component.
     */
    select: SelectComponent | null;
    /**
     * The selected values.
     */
    selectionForm: FormGroup;
    /**
     * The inboxState is used to get the active view name.
     * @private
     */
    private inboxState;
    /**
     * The inboxToolbarService is used to get if the attribute settings are closed
     */
    private inboxToolbarService;
    /**
     * The filterState is used to get the filter values from the filter toolbar.
     * @private
     */
    private filterState;
    /**
     * The destroyRef is used to destroy the component.
     * @private
     */
    private destroyRef;
    /**
     * Boolean if the component is initialized.
     * @private
     */
    private initialized;
    constructor();
    /**
     * Function is called when the component is initialized.
     */
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Function is necessary to delete the filter from the filter toolbar.
     * Furthermore, the previous filterings with the deleted filter will be ignored.
     * @param deleteOrClean Boolean if the filter should be deleted or cleaned.
     * @param alreadyReset Boolean if the filter was already reset.
     * @param mouseEvent The mouse event.
     */
    onDeleteOrCleanFilterFromToolbar(deleteOrClean: boolean, alreadyReset: boolean, mouseEvent?: MouseEvent): void;
    /**
     * Function is necessary to send the selected values to the parent component.
     * @param filterIdentifier The identifier of the filter.
     * @param event The selected value(s).
     */
    onValuesSelected(filterIdentifier: string, event: string | string[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectionFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SelectionFilterComponent, "talenra-selection-filter", never, { "filterLabel": { "alias": "filterLabel"; "required": false; }; "filterIdentifier": { "alias": "filterIdentifier"; "required": false; }; "possibleValues": { "alias": "possibleValues"; "required": false; }; "multiple": { "alias": "multiple"; "required": false; }; "filterType": { "alias": "filterType"; "required": false; }; }, { "valuesSelected": "valuesSelected"; "deleteOrCleanFilterFromToolbar": "deleteOrCleanFilterFromToolbar"; }, never, never, false, never>;
}
