import { OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { PresetGroup } from '../../shared/models/presetGroup.model';
import { AttributeItemSelector } from '../../shared/models/attributeItemSelector.model';
import * as i0 from "@angular/core";
/**
 * SortFilterComponent is used to display the sort filter in the filter toolbar.
 * @example
 * <talenra-sort-filter *ngIf="!inboxLayoutService.inboxConfiguration$.value.hideSortSelection" [presetGroups]="presetGroups"></talenra-sort-filter>
 */
export declare class SortFilterComponent implements OnInit, OnDestroy, OnChanges {
    /**
     * The presetGroups for the sort filter.
     */
    presetGroups: PresetGroup[];
    /**
     * The event emitter for the click of the close button.
     */
    closeClick: import("@angular/core").OutputEmitterRef<void>;
    /**
     * Maximal number of sort attributes that can be selected.
     */
    maxSortSelected: number;
    /**
     * List of available attributes for the sort selection.
     */
    allSortSelectionAttributes: AttributeItemSelector[];
    /**
     * List of selected attributes for the sort selection.
     */
    selectedSortSelectionAttributes: AttributeItemSelector[];
    /**
     * If true, the sort selection attribute will be reset.
     */
    resetSortSelectionAttribute: boolean;
    /**
     * Maps of attributeItems with desc / arc sorting information. DisplayedName's & identifiers with arc / desc are used in map.
     * Needed to sort the selected data items (sort logic).
     * @private
     */
    private activateSortingFlags;
    /**
     * List of identifiers of the selected sort attributes.
     * Needed to sort the selected data items (sort logic).
     * @private
     */
    private pickedSortListIdentifiers;
    /**
     * Cache for the sorting order of the selected sort attributes.
     * Needed to sort the selected data items (sort logic).
     * @private
     */
    private sortCache;
    /**
     * Maps of identifiers with desc / arc sorting information. DisplayedName's & identifiers with arc / desc are used in map.
     * Needed to sort the selected data items (sort logic).
     * @private
     */
    private activateSortingFlagsIdentifiers;
    /**
     * Class to interact with data-items-list-item
     * @private
     */
    private dataItemsClass;
    /**
     * The filter toolbar service.
     * @private
     */
    private filterToolbarService;
    /**
     * The inbox state service.
     * @private
     */
    private inboxState;
    /**
     * The update presets service.
     * @private
     */
    private updatePresetsService;
    /**
     * The changed values service.
     * @private
     */
    private changedValuesService;
    /**
     * The subscriptions of the sort filter component.
     * @internal
     */
    private subscriptions;
    /**
     * Initializes the sort filter component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes in the sort filter component.
     * @param changes The changes in the sort filter component.
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribes all subscriptions of the sort filter component.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Method to emit the close button and close the inbox detail view
     */
    onCloseClick(): void;
    /**
     *  Auxiliary method for sorting algorithm. Asc and desc sorting order for each active attribute is saved in hashmap.
     *  If undefined displayedName sort should start with default sorting order.
     *  @param displayedName The displayed name of the attribute.
     *  @param sortCategory The sort category.
     */
    startSorting(displayedName: string, sortCategory: string): void;
    /**
     * Resets all the chosen sorting attributes and searched text.
     */
    resetSort(): void;
    /**
     * Handles the change of the selected sort attributes selector.
     * @param $event The selected sort attributes selector change event.
     */
    selectedSortAttributesSelectorChange($event: AttributeItemSelector[]): void;
    /**
     * Handles the click on the selected sort attribute icon.
     * @param $event The selected sort attribute icon click event.
     */
    selectedAttributeIconClickEmitter($event: AttributeItemSelector): void;
    /**
     * Checks if the sort attribute.
     * @private
     */
    private applySorting;
    /**
     * Set all start and picked sorting attributes when changes in attributes settings are made.
     * @private
     */
    private setStartAndPickedSortingList;
    /**
     * Sets all sort preset groups for the active preset.
     */
    private setSortFilterFromPresetGroups;
    /**
     * Save the sort filter for specific preset.
     * @private
     */
    private setSortFilterForPresetGroups;
    /**
     * If sortArray has changed compared to the presetGroups then the attributeSortOrFilterUsedSubject$ is set to true.
     * Check presetGroups are available.
     * @private
     */
    private recognizeIfSortFilterChanged;
    /**
     * Sorts the data items by the selected attributes and selected order.
     * @param dataItems The data items to sort.
     */
    private sort;
    /**
     * Sorts the selected data items by the given attribute.
     * @param key The identifier of the attribute to sort by.
     * @param cb The sorting direction.
     * @internal
     * @private
     */
    private sortBy;
    /**
     * Sorts the selected data items by the given attribute in descending order.
     * @param key The identifier of the attribute to sort by.
     * @param cb The sorting direction.
     * @internal
     * @private
     */
    private sortByDesc;
    /**
     * Sorts the selected data items by their id.
     * @private
     */
    private defaultSort;
    /**
     * Sorts the selected data items by the given attributes.
     * @param keys The identifiers of the attributes to sort by.
     * @param orders The sorting directions.
     * @internal
     * @private
     */
    private orderBy;
    /**
     * Checks if sorting is possible. If yes, the identifier of the attribute will be saved in pickedSortListIdentifiers.
     * @private
     */
    private checkIfSortingPossible;
    /**
     * Resets the sort filter component on initialization.
     * @private
     */
    private resetOnInit;
    /**
     * Sets the active filter, sort and search service state.
     * @private
     */
    private setActiveFilterSortSearchServiceState;
    /**
     * Initializes the component.
     * @private
     */
    private initializeComponent;
    static ɵfac: i0.ɵɵFactoryDeclaration<SortFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SortFilterComponent, "talenra-sort-filter", never, { "presetGroups": { "alias": "presetGroups"; "required": false; }; }, { "closeClick": "closeClick"; }, never, never, false, never>;
}
