import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { BehaviorSubject } from 'rxjs';
import { MatMenuTrigger } from '@angular/material/menu';
import { InboxToolbarService } from './inbox-toolbar.service';
import { CheckboxState } from '../shared/models/checkbox.types';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { PresetGroup } from '../shared/models/presetGroup.model';
import { InboxDetailViewService } from '../inbox-layout/inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from '../inbox-layout/data-items-list/data-items.service';
import { InboxState } from '../inbox/state/inbox.state';
import * as i0 from "@angular/core";
/**
 * The toolbar is an important component that allows to access needed data from the data items list faster and increase
 * the usability.
 *
 * ```html
 * <talenra-inbox-toolbar
 *   fcn="{{searchFieldFcn}}"
 *   label="{{searchFieldLabel}}"
 *   [maxLength]="searchFieldMaxLength"
 *   [searchForm]="searchField"
 *   [disabledButtons]="disabledButtons"
 *   [checkedForm]="checkedForm"
 *   (iconBtn)="iconBtnFunction($event)"
 * ></talenra-inbox-toolbar>
 * ```
 */
export declare class InboxToolbarComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * Input to define the pre-set options group.
     */
    presetGroups: PresetGroup[];
    /**
     * Identifies the form-control which is part of the form-group.
     */
    fcn: string;
    /**
     * Input to define the maximum length of the input field.
     */
    maxLength?: number;
    /**
     * The form-group which defines the overall form consisting most of the time
     * of multiple inputs, gets passed into the component.
     */
    searchForm: FormGroup;
    /**
     * Input to disable checkbox behavior and UI.
     */
    disableBulkInteractionButtons: boolean;
    /**
     * Input to disable the detail view tab change button in the toolbar and set it to a fixed state.
     * Used to set state if no data items are found.
     */
    fixDisableDetailViewToggle: boolean;
    /**
     * Number of marked data items.
     */
    numberMarkedDataItems: number;
    /**
     * Boolean to show if the data is to be refreshed.
     */
    refreshing: boolean;
    /**
     * Checkbox state of the toolbar checkbox.
     */
    checkboxState: CheckboxState;
    /**
     * EventEmitter for icon button clicks.
     */
    iconBtn: EventEmitter<string>;
    /**
     * EventEmitter for icon button clicks.
     */
    presetInteractions: EventEmitter<string>;
    /**
     * EventEmitter to delete preset.
     */
    deletePreset: EventEmitter<[string, string]>;
    /**
     * EventEmitter to change preset name
     */
    changePresetName: EventEmitter<[string, string, string]>;
    /**
     * Emitter for the change in the checkbox state of the toolbar checkbox.
     */
    checkboxStateChange: EventEmitter<CheckboxState>;
    /**
     * Child of the toolbar mat-menu.
     */
    condensedMenuTrigger: MatMenuTrigger | undefined;
    /**
     * Child of the toolbar mat-menu.
     */
    talenraInboxToolbarMenuTrigger: MatMenuTrigger | undefined;
    /**
     * Form for checkbox interaction.
     */
    checkedForm: FormGroup;
    /**
     * List style for the checkbox behavior and UI.
     */
    checkboxIndeterminate: boolean;
    /**
     * Observable which contains the width of the component.
     */
    width$: BehaviorSubject<number>;
    /**
     * The width of the line break setting.
     */
    LINEBREAKWIDTH: number;
    /**
     * The inbox service.
     */
    inboxState: InboxState;
    /**
     * The inbox detail view service.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * The data items service.
     */
    dataItemsService: DataItemsService;
    /**
     * The inbox toolbar service.
     */
    inboxToolbarService: InboxToolbarService;
    /**
     * The keyboard service.
     * @internal
     * @private
     */
    keyboardService: KeyboardService;
    /**
     * Semaphore to stop accessing checkbox value a second time.
     * @internal
     */
    private checkboxSemaphore;
    /**
     * The subscriptions of the inbox toolbar component.
     * @internal
     * @private
     */
    private subscriptions;
    /**
     * The observable for the resize event.
     * @internal
     * @private
     */
    private resizeObservable$;
    /**
     * The subscription to the resize observable.
     * @internal
     * @private
     */
    private resizeSubscription$;
    /**
     * The element reference.
     * @internal
     * @private
     */
    private elementRef;
    /**
     * The zone.
     * @internal
     * @private
     */
    private zone;
    /**
     * Initializes the subscriptions of the resize observable.
     * @internal
     */
    private observer;
    /**
     * Initializes the inbox toolbar component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Called when the component input is changed.
     * @internal
     * @param changes The changes of the component.
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribes and unobserved from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Click event emit that attribute settings side panel will open.
     * @param {MouseEvent} event Click event.
     */
    onShowAttributesSettingsClick(event: MouseEvent): void;
    /**
     * Click event emit that inbox detail view side panel will close.
     * @param {MouseEvent} event Click event.
     */
    onDetailsClick(event: MouseEvent): void;
    /**
     * Click event emit that 'unfold-less' and 'unfold-more' icon will switch.
     * @param {MouseEvent} event Click event.
     */
    onCompressClick(event: MouseEvent): void;
    /**
     * Click event emit that filter options can be viewed.
     * @param {MouseEvent} event Click event.
     */
    onFilterListClick(event: MouseEvent): void;
    /**
     * Click event emit that opens the preset.
     */
    stopPropagation(event: MouseEvent): void;
    /**
     * Click event emit that a CSV can be downloaded.
     * @param {MouseEvent} event Click event.
     */
    onDownloadClick(event: MouseEvent): void;
    /**
     * Click event emit that more actions can be seen.
     * @param {string} source The source of the click event.
     */
    onGetActionsClick(source?: string): void;
    /**
     * Click event emit that the process can start.
     */
    onStartProcessClick(): void;
    /**
     * Handler for the preset interactions.
     * @param event The event of the preset interactions.
     */
    onPresetInteractions(event: string): void;
    /**
     * Click event emit that the refresh btn is clicked.
     */
    onRefreshClick(): void;
    /**
     * Handles the closing of the action menu.
     * Sets the value for the public api.
     */
    onActionsMenuClosed(): void;
    /**
     * Handles the opening of the action menu if accessed by a subscription.
     * @param value The value of the subscription.
     */
    interactionActionMenuSubscriptions(value: boolean): void;
    /**
     * Changes the checkbox state in the form.
     * @param value The value of the checkbox state.
     * @private
     */
    private changeCheckboxState;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InboxToolbarComponent, "talenra-inbox-toolbar", never, { "presetGroups": { "alias": "presetGroups"; "required": false; }; "fcn": { "alias": "fcn"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "searchForm": { "alias": "searchForm"; "required": false; }; "disableBulkInteractionButtons": { "alias": "disableBulkInteractionButtons"; "required": false; }; "fixDisableDetailViewToggle": { "alias": "fixDisableDetailViewToggle"; "required": false; }; "numberMarkedDataItems": { "alias": "numberMarkedDataItems"; "required": false; }; "refreshing": { "alias": "refreshing"; "required": false; }; "checkboxState": { "alias": "checkboxState"; "required": false; }; }, { "iconBtn": "iconBtn"; "presetInteractions": "presetInteractions"; "deletePreset": "deletePreset"; "changePresetName": "changePresetName"; "checkboxStateChange": "checkboxStateChange"; }, never, ["[custom-toolbar-space]", "[further-actions-menu]"], false, never>;
}
