import { EventEmitter } from '@angular/core';
import { BehaviorSubject, Subscription } from 'rxjs';
import { FormGroup } from '@angular/forms';
import { KeyboardService } from './keyboard.service';
import { DetailViewItemModel } from '../../shared/models/detailViewItem.model';
import { AttributeItem } from '../../shared/models/attributeItem.model';
import { AttributeItemInput } from '../../shared/models/attributeItemInput.model';
import { IconInput } from '../../shared/models/iconInput.model';
import { FilterToolbarService } from '../../filter-toolbar/filter-toolbar.service';
import { InboxState } from '../state/inbox.state';
import { DataItemIdModel } from '../../shared/models/dataItemId.model';
import { InteractedDataItemsModel } from '../../shared/models/interactedDataItems.model';
import { InboxDetailViewService } from '../../inbox-layout/inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from '../../inbox-layout/data-items-list/data-items.service';
import * as i0 from "@angular/core";
export declare class MainFacadeSetterService {
    /**
     * The form-group defines the search field, gets passed into the component.
     */
    searchField: FormGroup;
    /**
     * The maximum Attributes, which are to be shown in the data-items-list.
     * Further they are divided in the ui.
     * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings.
     * Default value is 12, like chosen in the requirements.
     */
    maxMainAttributes: number;
    /**
     * The maximum Attributes, which are to be shown in the detail-view.
     * Default value is 100, like chosen in the requirements.
     */
    maxAttributesDetail: number;
    /**
     * The list of all attributes generated by the attributes input supplied by the consuming app or generated by the data
     * items if the attributes are not supplied by the consuming application.
     */
    allAttributes$: BehaviorSubject<AttributeItem[]>;
    /**
     * The list of all attributes supplied by the consuming app.
     */
    allUntransformedAttributes$: BehaviorSubject<AttributeItemInput[]>;
    /**
     * The number of main attributes chosen by the user.
     * Default value is 12, like chosen in the requirements. Will be overwritten by the consuming app through the view  or inbox configuration.
     */
    numberMainAttributesChosenByUser$: BehaviorSubject<number>;
    /**
     * The selection of icons that are to be used to filter and flag the data items.
     */
    iconSelection$: BehaviorSubject<IconInput[]>;
    /**
     * The position of the virtual scroller.
     */
    virtualScrollerPosition$: BehaviorSubject<number>;
    /**
     * Flag to check if the detail view is expanded or not and should be opened after data items refresh.
     */
    reOpenDetailViewAfterRefresh: boolean | undefined;
    /**
     * The subscription for the inbox.
     * @internal
     */
    subscriptions: Subscription;
    /**
     * The subscriptions of the detail view.
     * @internal
     */
    detailViewSubscriptions: Subscription;
    /**
     * The service of the data items.
     */
    dataItemsService: DataItemsService;
    /**
     * The service of the keyboard.
     */
    keyboardService: KeyboardService;
    /**
     * The service of the filter toolbar.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The state of the inbox.
     */
    inboxState: InboxState;
    /**
     * The service of the inbox detail view.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * Class to interact with data items.
     */
    private dataItemsClass;
    /**
     * The value if the side panel is to be shown after no results found.
     */
    private reopenInboxDetailView;
    /**
     * Data items which are filtered by the search.
     */
    private searchedDataItems;
    /**
     * Initial Attributes for the detail-view.
     * Used to initialize the attribute to the correct list (detail).
     */
    private dataItemsListAttributesDetail;
    /**
     * Initial Attributes for the data-items-list.
     * Used to initialize the attribute to the correct list (main).
     */
    private dataItemsListAttributesMain;
    /**
     * Sets the attribute list.
     * @param attributeList The attribute list.
     */
    setAllAttributes(attributeList: AttributeItem[]): void;
    /**
     * Sets the untransformed attribute list.
     * @param dataItemAttributes The untransformed attribute list.
     */
    setAllUntransformedAttributes(dataItemAttributes: AttributeItemInput[]): void;
    /**
     * Sets the number of main attributes chosen by the user.
     * @param numberMainAttributesChosenByUser The number of main attributes chosen by the user.
     */
    setNumberMainAttributesChosenByUser(numberMainAttributesChosenByUser: number): void;
    /**
     * Sets the icon selection.
     * @param iconAttribute The icon selection.
     */
    setIconSelection(iconAttribute: IconInput[]): void;
    /**
     * Sets the virtual scroller position.
     * @param virtualScrollerPosition The virtual scroller position.
     */
    setVirtualScrollerPosition(virtualScrollerPosition: number): void;
    /**
     * Sets the detail view tabs after view init of the consuming app.
     * @param detailViewTabsChanges Changes of the detail view tabs.
     */
    resetDetailViewTabs(detailViewTabsChanges: DetailViewItemModel[]): DetailViewItemModel[];
    /**
     * Sets the picked attributes for the attributes-settings.
     * Used to initialize the attributeList, if attributes are defined by consuming app.
     */
    setPickedAttributes(): void;
    /**
     * Sets the selected dataItemListAttributes in the attributes-settings-service (SELECTED = CHECKED).
     * The attributes-settings-service is used to communicate with the attributes-settings (main and detail attributes).
     */
    setSelectedAttributeListInsideAttributesSettingsService(): void;
    /**
     * Determines the order of the picked data-item-list attributes.
     * @param mainAttributesData Main attributes.
     * @param detailsAttributesData Detail attributes.
     */
    determineOrderOfPickedAttributes(mainAttributesData: AttributeItem[], detailsAttributesData: AttributeItem[]): void;
    /**
     * All changes through the filter-toolbar and the search-field inside inbox-toolbar are subscribed.
     * The displayed data-item-list adept to the filter changes.
     */
    setFilterAndSearchSubscriptions(clickedDataItemEmitter: any): void;
    /**
     * Initializes the data items list.
     * @param dataItems The data items.
     */
    initializeDataItemsList(dataItems: any[]): void;
    /**
     * Handler for the data items when no data items are found.
     * @internal
     */
    noDataItemsFound(): void;
    /**
     * Sets the necessary properties in the keyboard-service.
     * Allows the keyboard-service to access the properties of the inbox-component.
     */
    setKeyboardServiceConfiguration(dataItemInformationTabBarItems: DetailViewItemModel[], iconBtnFunction: (btn: string) => void, dataItemsInteractions: EventEmitter<InteractedDataItemsModel>, dataItemsAvailable: boolean, dataItemSelectedFunction: (dataItem: any) => void, clickedDataItemEmitter: EventEmitter<any>, lockedDataItems: DataItemIdModel[]): void;
    /**
     * Sets the default value of expanded detailView, selectedDataItem and selectedItem of detailView.
     */
    setDefaultStateOfInboxLayout(dataItems: any, clickedDataItemEmitter: any): void;
    /**
     * Handler for the clicked data item.
     * @param dataItem The clicked data item.
     * @param clickedDataItemEmitter The clicked data item emitter.
     */
    clickedDataItemFunction(dataItem: any, clickedDataItemEmitter: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MainFacadeSetterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MainFacadeSetterService>;
}
