import { BehaviorSubject } from 'rxjs';
import { MainFacadeSetterService } from './main-facade-setter.service';
import { PresetGroup } from '../../shared/models/presetGroup.model';
import { FilterToolbarService } from '../../filter-toolbar/filter-toolbar.service';
import { AttributeItem } from '../../shared/models/attributeItem.model';
import { SortAttributesInput } from '../../shared/models/sortAttributesInput.model';
import { SelectedAttributesInput } from '../../shared/models/selectedAttributesInput.model';
import { InboxState } from '../state/inbox.state';
import { TPresetOperations } from '../../shared/models/presetAction.model';
import * as i0 from "@angular/core";
/**
 * Service to update the presets and check if the inbox has changed.
 */
export declare class UpdatePresetsService {
    /**
     * Containing the current preset action which is to emit to the consuming application.
     */
    currentPresetAction$: BehaviorSubject<{
        operation: TPresetOperations;
        groupName: string;
        presetName?: string;
        newPresetName?: string;
    }>;
    /**
     * The presets group that are to be emitted to the consuming application.
     */
    currentPresetGroup$: BehaviorSubject<PresetGroup[]>;
    /**
     * The preset that is to be renamed.
     * [groupName, presetName, newPresetName]
     */
    currentRenamedPreset$: BehaviorSubject<string[]>;
    /**
     * The name of the new preset is saved here.
     * [groupName, presetName]
     */
    newPresetName$: BehaviorSubject<string[]>;
    /**
     * All preset names are saved here.
     */
    presetNames$: BehaviorSubject<string[][]>;
    /**
     * all selected attributes are saved here.
     */
    selectedAttributes: SelectedAttributesInput[];
    /**
     * The filter toolbar service.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The main facade setter service.
     */
    mainFacadeSetterService: MainFacadeSetterService;
    /**
     * The inbox state.
     */
    inboxState: InboxState;
    /**
     * The selected main attributes.
     * TODO: check if value can be obtained from the state, not via subscription
     */
    private selectedAttributesSubject;
    /**
     * The selected detail attributes.
     * TODO: check if value can be obtained from the state, not via subscription
     */
    private selectedAttributesDetailsSubject;
    /**
     * The maximum Attributes, which are to be shown in the data-items-list mutated by the user.
     * TODO: check if value can be obtained from the state, not via subscription
     */
    private numberMainAttributesChosenByUserSubject;
    /**
     * The selected sort Subjects.
     * TODO: check if value has to be initialized a second time in the service
     * @private
     */
    private sortSubject;
    /**
     * The selected filter Subjects.
     * TODO: check if value can be obtained from the state, not via subscription
     * @private
     */
    private filterAttributesWithValuesSubject;
    /**
     * Set the current preset action.
     * @param presetAction
     */
    setCurrentPresetAction(presetAction: {
        operation: TPresetOperations;
        groupName: string;
        presetName?: string;
        newPresetName?: string;
    }): void;
    /**
     * Set the current preset action.
     */
    resetCurrentPresetAction(): void;
    /**
     * Set the preset groups.
     * @param presetGroups The presets group.
     */
    setCurrentPresetGroup(presetGroups: PresetGroup[]): void;
    /**
     * Set the current renamed preset.
     * @param renamedPreset The renamed preset. [groupName, presetName, newPresetName]
     */
    setCurrentRenamedPreset(renamedPreset: string[]): void;
    /**
     * Set the new preset name.
     * @param newPresetName The new preset name. [groupName, presetName]
     */
    setNewPresetName(newPresetName: string[]): void;
    /**
     * Set the preset names.
     * @param presetNames The preset names.
     * @private
     */
    setPresetNames(presetNames: string[][]): void;
    /**
     * Method to change visibility of preset in preset groups.
     * @param presetName The [groupName, presetName]
     * @param visibility boolean
     */
    changeVisibilityOfPresetInPresets(presetName: string[], visibility: boolean): void;
    /**
     * Method to delete a preset in preset groups.
     * @param presetName The [groupName, presetName]
     */
    deletePresetInPresets(presetName: string[]): void;
    /**
     * Change the name of a preset.
     * @param presetName The [groupName, presetName, newPresetName]
     */
    renamePresetInPresets(presetName: string[]): void;
    /**
     * Method to change the position of presets in preset groups.
     * @param groupName The group name.
     * @param presetName The preset name.
     * @param upOrDown Boolean to indicate if the preset should be moved up or down.
     */
    changePositionOfPresetInPresets(groupName: string, presetName: string, upOrDown: boolean): void;
    /**
     * Method to swap presets in preset groups.
     * @param groupName The group name.
     * @param presetNameOne The first preset name.
     * @param presetNameTwo The second preset name.
     */
    swapPresetInPresets(groupName: string, presetNameOne: string, presetNameTwo: string): void;
    /**
     * Method to change the position of presets in preset groups.
     * @param event The position change event. [groupName, presetName, upOrDown]
     */
    dragDropPresetInPresets(event: any): void;
    /**
     * Method to set the new/overwrite preset groups for the preset.
     * @param command The command to execute.
     * @param attributesUsed Boolean to indicate if attributes are used.
     */
    setAllNewSettingsForPreset(command: string, attributesUsed?: boolean): void;
    /**
     * Set the main attributes to the new preset.
     * @param event Selected attributes.
     */
    setMainAttributesToNewPreset(event: AttributeItem[]): void;
    /**
     * Set the details attributes to the new preset.
     * @param event Selected attributes.
     */
    setDetailsAttributesToNewPreset(event: AttributeItem[]): void;
    /**
     * Set the sort filter to the new preset.
     * @param event Selected sort filters.
     */
    setSortFilterToNewPreset(event: SortAttributesInput[]): void;
    /**
     * Set the visibility to the new preset.
     * @param event Selected visibility.
     */
    setVisibilityToNewPreset(event: boolean): void;
    /**
     * Set the number of main attributes to the new preset.
     * @param event
     */
    setNumberMainAttributesChosenByUserToPreset(event: number): void;
    /**
     * Set the filter to the new preset.
     * @param event Selected filters.
     */
    setFilterToNewPreset(event: Map<string, [string, string | boolean | string[] | number[] | Date[]]>): void;
    /**
     * Auxiliary method to check if item is unique.
     * @param value Item to check.
     * @param index Index of item.
     * @param self Item to check.
     * @internal
     */
    onlyUnique(value: any, index: number, self: any): boolean;
    /**
     * Method to check if an array is in a multidimensional array.
     * @param arr The array.
     * @param target The target array.
     * @internal
     */
    isArrayInMultidimensionalArray(arr: any[][], target: any[]): boolean;
    /**
     * Method to update the attributes in the preset groups.
     * @param presetName The preset to update. [groupName, presetName]
     * @param selectedAttributes The selected attributes.
     */
    updateAttributeInPresets(presetName: string[], selectedAttributes: string[]): void;
    /**
     * Updates current presetGroups in state. Also emits the new presetGroups via setting the current presetGroups.
     * @param presetGroups The new presetGroups.
     */
    private updatePresetGroupAndNotify;
    /**
     * Helper method to update a preset in preset groups.
     * @param presetName The preset to update.
     * @param updateFunc The function to update the preset.
     */
    private updatePresetInPresets;
    static ɵfac: i0.ɵɵFactoryDeclaration<UpdatePresetsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UpdatePresetsService>;
}
