import { BehaviorSubject } from 'rxjs';
import { AttributeItem } from '../../shared/models/attributeItem.model';
import { PresetGroup } from '../../shared/models/presetGroup.model';
import { Preset } from '../../shared/models/preset.model';
import { FilterSortSearchModel } from '../../shared/models/filterSortSearch.model';
import { BufferFilterSort } from '../../shared/models/bufferFilterSort.model';
import { InboxConfigurationModel } from '../../shared/models/inboxConfiguration.model';
import * as i0 from "@angular/core";
/**
 * Provides control and state of the publicly available subjects of the inbox state.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxState } from '@talenra/ngx-inbox';
 * ```
 */
export declare class InboxState {
    /**
     * Provides the inbox configuration.
     */
    readonly inboxConfiguration$: BehaviorSubject<InboxConfigurationModel>;
    /**
     * Provides whether the action menu (mat-menu) is expanded or not.
     * @Usage data items and inbox toolbar
     */
    readonly actionMenuExpanded$: BehaviorSubject<boolean>;
    /**
     * The actions menu click flag.
     * This flag is used to prevent an infinite loop of the actions menu opening, when the inbox is setting it to true.
     * @internal
     */
    readonly actionsMenuClickFlag: BehaviorSubject<boolean>;
    /**
     * Provides the selected main attributes.
     */
    readonly selectedMainAttributesSubject$: BehaviorSubject<AttributeItem[]>;
    /**
     * Provides the selected detail attributes.
     */
    readonly selectedDetailAttributesSubject$: BehaviorSubject<AttributeItem[]>;
    /**
     * Provides  all selected attributes.
     */
    readonly selectedAllAttributesSubject$: BehaviorSubject<AttributeItem[]>;
    /**
     * Provides the active preset.
     */
    readonly activePreset$: BehaviorSubject<Preset>;
    /**
     * Data items which are filtered and sorted.
     */
    readonly filteredDataItemsSubject$: BehaviorSubject<any[]>;
    /**
     * All preSetOptionsGroups which are available.
     * @internal
     */
    readonly presetGroups$: BehaviorSubject<PresetGroup[]>;
    /**
     * The preset name of the active view.
     * @internal
     */
    readonly activePresetName$: BehaviorSubject<string[]>;
    /**
     * The selected tab.
     * @internal
     */
    selectedSidePanelTab: import("@angular/core").WritableSignal<string>;
    /**
     * The active filters, sort and search information.
     */
    readonly activeFilterSortSearch: BehaviorSubject<FilterSortSearchModel>;
    /**
     * The buffer filters and sort filters which are not saved in the presets.
     * @internal
     */
    readonly bufferFilterSort: BehaviorSubject<BufferFilterSort>;
    /**
     * Updates the inbox configuration.
     *
     * @param configuration The new inbox configuration.
     */
    setInboxConfiguration(configuration: InboxConfigurationModel): void;
    /**
     * Collapses or expands the side-navigation
     *
     * @param isExpanded Whether the action-menu is expanded or not.
     */
    setActionMenuExpanded(isExpanded: boolean): void;
    /**
     * Sets the actions menu click flag.
     * @param value The value to set.
     * @internal
     */
    setActionsMenuClickFlag(value: boolean): void;
    /**
     * Sets the selected main attributes for the filter toolbar.
     * @param selectedMainAttributes The selected main attributes.
     * @internal
     */
    setSelectedMainAttributesSubject(selectedMainAttributes: AttributeItem[]): void;
    /**
     * Sets the selected detail attributes for the filter toolbar.
     * @param selectedDetailAttributes The selected detail attributes.
     * @internal
     */
    setSelectedDetailAttributesSubject(selectedDetailAttributes: AttributeItem[]): void;
    /**
     * Sets the selected all attributes for the filter toolbar.
     * @param selectedAllAttributes The selected all attributes.
     * @internal
     */
    setSelectedAllAttributesSubject(selectedAllAttributes: AttributeItem[]): void;
    /**
     * Sets the active view for the filter toolbar.
     * @param activeView The active view.
     * @internal
     */
    setActivePreset(activeView: Preset): void;
    /**
     * Sets the filtered data items.
     * @param filteredDataItems The filtered data items.
     * @internal
     */
    setFilteredDataItemsSubject(filteredDataItems: any[]): void;
    /**
     * Sets the preSetOptionsGroups.
     * @param key The preSetOptionsGroups.
     * @internal
     */
    setPresetGroups(key: PresetGroup[]): void;
    /**
     * Sets the active view name.
     * @param key The active view name.
     * @internal
     */
    setActivePresetName(key: string[]): void;
    /**
     * Sets the active filter sort search.
     * @param key The active filter sort search.
     * @internal
     */
    setActiveFilterSortSearch(key: FilterSortSearchModel): void;
    /**
     * Sets the buffer filter and sort.
     * @param key The buffer filter and sort.
     * @internal
     */
    setBufferFilterSort(key: BufferFilterSort): void;
    /**
     * Resets the buffer filter and sort to contain empty maps and arrays.
     * @internal
     */
    resetBufferFilterSort(): void;
    /**
     * Sets the selected side panel tab.
     * @param tab The selected side panel tab.
     */
    setSelectedSidePanelTab(tab: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxState, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InboxState>;
}
