/**
 * FilterAttribute is used to filter the data based on the selected attributes.
 * **Important Information:**
 *
 * 1. **The identifier must already be used in selectedAttributes (SelectedAttributesInput[]).**
 *
 * ```typescript
 * import { FilterAttribute } from '@talenra/ngx-inbox';
 *
 * const filterAttributeMultiSelect: FilterAttribute = { identifier: 'animal.mammal', value: [{ key: 'landAnimalMonkey', label: 'Monkey' }, { key: 'waterAnimalWhale', label: 'Whale' }] };
 * const filterAttributeSingleSelect: FilterAttribute = { identifier: 'animal.mammal', value: { key: 'waterAnimalWhale', label: 'Whale' } };
 * const filterAttributeCharRange: FilterAttribute = { identifier: 'animal.mammal', value: { start: 'AR', end: 'JAB' } };
 * const filterAttributeNumberRange: FilterAttribute = { identifier: 'animal.weight.kg', value: { start: 50, end: 1600 } };
 * const filterAttributeDateRange: FilterAttribute = { identifier: 'animal.birthDate', value: { start: new Date('01.14.2023'), end: new Date('01.14.2024') } };
 * ```
 */
export interface FilterAttribute {
    /**
     * As the filter types are already defined in {@link AttributeItemInput}, only the identifier and values for the filter are necessary to set.
     */
    identifier: string;
    /**
     * The values are defined for the filter modes ({@link AttributeItemInput}) as:
     *
     * - single-select: SelectionFilterValue
     * - multi-select: SelectionFilterValue[]
     * - char-range: CharRangeFilterValue
     * - number-range: NumberRangeFilterValue
     * - date-range: DateRangeFilterValue
     */
    value: SelectionFilterValue | SelectionFilterValue[] | CharRangeFilterValue | NumberRangeFilterValue | DateRangeFilterValue;
}
/**
 * FilterValue is used to correlate a filter value with a key and label.
 * Enables the to display a label and identify the value by a key.
 *
 * ```typescript
 * import { SelectionFilterValue } from '@talenra/ngx-inbox';
 * const filterValue: SelectionFilterValue = { key: '8001', label: 'John Doe' };
 * ```
 */
export interface SelectionFilterValue {
    /**
     * Key that identifies the value.
     */
    key: string;
    /**
     * Label that is displayed for the value.
     */
    label: string;
}
/**
 * Is used to define a character range filter value.
 *
 * ```typescript
 * import { CharRangeFilterValue } from '@talenra/ngx-inbox';
 * const charRangeFilterValue: CharRangeFilterValue = { start: 'AR', end: 'JAB' };
 * ```
 */
export interface CharRangeFilterValue {
    /**
     * Start value of the character range.
     */
    start: string;
    /**
     * End value of the character range.
     */
    end: string;
}
/**
 * Is used to define a number range filter value.
 *
 * ```typescript
 * import { NumberRangeFilterValue } from '@talenra/ngx-inbox';
 * const numberRangeFilterValue: NumberRangeFilterValue = { start: 1, end: 6 };
 * ```
 */
export interface NumberRangeFilterValue {
    /**
     * Start value of the number range.
     */
    start: number;
    /**
     * End value of the number range.
     */
    end: number;
}
/**
 * Is used to define a date range filter value.
 *
 * ```typescript
 * import { DateRangeFilterValue } from '@talenra/ngx-inbox';
 * const dateRangeFilterValue: DateRangeFilterValue = { start: new Date('01.14.2023'), end: new Date('01.14.2024') };
 * ```
 */
export interface DateRangeFilterValue {
    /**
     * Start value of the date range.
     */
    start: Date;
    /**
     * End value of the date range.
     */
    end: Date;
}
