import { FilterAttributesInput } from './filterAttributesInput.model';
import { IconFiltersInput } from './iconFiltersInput.model';
import { SelectedAttributesInput } from './selectedAttributesInput.model';
import { SortAttributesInput } from './sortAttributesInput.model';
/**
 * Preset is used to define a specific preset for the inbox.
 *
 * @example
 * import { Preset } from '@talenra/ngx-inbox';
 *
 * const presets: Preset = {
 *   identifier: '121bd936-ce20-4ea9-9dc1-6cdaf61f9c3d',
 *   name: 'Meine Inbox',
 *   changeable: false,
 *   selectedAttributes:
 *     [
 *       { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *       { identifier: 'case.caseID', defaultAttribute: 'detail' },
 *     ],
 *   children:
 *     [
 *       {
 *         name: 'View 1',
 *         numberMainAttributesChosenByUser: 4,
 *         selectedAttributes: [
 *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *           { identifier: 'case.caseID', defaultAttribute: 'main' },
 *           { identifier: 'processStep', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
 *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.socialSecurityNumber', defaultAttribute: 'detail' },
 *           { identifier: 'case.casePriority', defaultAttribute: 'main' },
 *         ],
 *         sortAttributes: [
 *           { identifier: 'case.caseTypeName', sort: 'asc' },
 *           { identifier: 'insuree.socialSecurityNumber', sort: 'desc' },
 *         ],
 *         filterAttributes: [
 *           {
 *             identifier: 'case.caseTypeName',
 *             value: ['Direkt eingegangene Beschwerde'],
 *           },
 *           {
 *             identifier: 'case.caseStartDate',
 *             value: [new Date('01.15.2020'), new Date('12.30.2023')],
 *           },
 *           { identifier: 'case.casePriority', value: [1, 2] },
 *         ],
 *         iconAttributes: [],
 *       },
 *       {
 *         name: 'View 2',
 *         numberMainAttributesChosenByUser: 4,
 *         selectedAttributes: [
 *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *           { identifier: 'case.caseID', defaultAttribute: 'main' },
 *           { identifier: 'processStep', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
 *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
 *         ],
 *         sortAttributes: [{ identifier: 'case.caseTypeName', sort: 'asc' }],
 *         filterAttributes: [
 *           {
 *             identifier: 'case.caseTypeName',
 *             value: ['Direkt eingegangene Beschwerde'],
 *           },
 *         ],
 *         iconAttributes: [],
 *       },
 *     ],
 * };
 */
export interface Preset {
    /**
     * Optional string to identify the item.
     * Used to identify the preset in the sidenav.
     */
    identifier?: string;
    /**
     * Name is used to define the name of the preset.
     **/
    name: string;
    /**
     * Visible attribute is used to define if the preset is visible in the sidenav or not.
     */
    visible?: boolean;
    /**
     * Changeable is used to define if the preset is changeable in the inbox or not.
     * Disable the option for user to overwrite the preset.
     */
    changeable?: boolean;
    /**
     * The number of chosen main attributes that are to be displayed in the attributes settings and data items list.
     */
    numberMainAttributesChosenByUser?: number;
    /**
     * The selectedAttributes is used to define which attributes are selected and displayed in the main or detail section.
     * If an attribute is not chosen, it will be displayed as unselected.
     */
    selectedAttributes: SelectedAttributesInput[];
    /**
     * SortAttributes is used to define which attributes are used to sort the items in the inbox.
     */
    sortAttributes?: SortAttributesInput[];
    /**
     * FilterAttributes is used to define which attributes are used to filter the items in the inbox.
     * Make sure to use only attributes which are already used in selectedAttributes (SelectedAttributesInput[])
     */
    filterAttributes?: FilterAttributesInput[];
    /**
     * IconAttributes is used to define which icon filters are active in the inbox.
     */
    iconAttributes?: IconFiltersInput[];
    /**
     * Children are used to define if the preset has child presets.
     */
    children?: Preset[];
}
